<?php
/**
 * functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 */

/**
 * Define variables
 */

defined( 'KABLE_THEME_DIR' )        or   define( 'KABLE_THEME_DIR',          trailingslashit( get_template_directory() ) );
defined( 'KABLE_THEME_URI' )        or   define( 'KABLE_THEME_URI',          trailingslashit(get_template_directory_uri()) );
defined( 'KABLE_INC_DIR' )          or   define( 'KABLE_INC_DIR',            trailingslashit(KABLE_THEME_DIR . 'inc' ));
defined( 'KABLE_INC_URI' )          or   define( 'KABLE_INC_URI',            KABLE_THEME_URI  . 'inc/admin/theme/assets/' );
defined( 'KABLE_JS' )               or   define( 'KABLE_JS',                 KABLE_THEME_URI  . 'assets/js' );
defined( 'KABLE_CSS' )              or   define( 'KABLE_CSS',                KABLE_THEME_URI . 'assets/css' );
defined( 'KABLE_IMAGE' )            or   define( 'KABLE_IMAGE',              KABLE_THEME_URI . 'assets/images' );
defined( 'KABLE_PLUGIN' )           or   define( 'KABLE_PLUGIN',             KABLE_THEME_URI . 'assets/plugin' );
defined( 'KABLE_OPTIONS_PRESET' )   or   define( 'KABLE_OPTIONS_PRESET',     KABLE_INC_DIR . 'presets' );
defined( 'KABLE_THEME_VERSION' )    or   define( 'KABLE_THEME_VERSION',      wp_get_theme()->get('Version') );



if (!function_exists('kable_inc_library')) {
    function kable_inc_library(){
        require_once(KABLE_INC_DIR . 'admin/image-resize.php');
        require_once(KABLE_INC_DIR . 'admin/mega-menu.php');
        require_once(KABLE_INC_DIR . 'admin/plugin-activation/class-tgm-plugin-activation.php');
        require_once(KABLE_INC_DIR . 'admin/plugin-activation/plugin-init.php');
        require_once(KABLE_INC_DIR . 'admin/theme-options.php');
        require_once(KABLE_INC_DIR . 'admin/importer/importer.php');
        require_once(KABLE_INC_DIR . 'conditional.php');
        require_once(KABLE_INC_DIR . 'theme-setup.php');
        require_once(KABLE_INC_DIR . 'theme-functions.php');
        require_once(KABLE_INC_DIR . 'admin-enqueue.php');        
        require_once(KABLE_INC_DIR . 'layout/pre-loader.php');
        require_once(KABLE_INC_DIR . 'layout/wmpl-switcher.php');
        require_once(KABLE_INC_DIR . 'layout/breadcrumbs.php');
        require_once(KABLE_INC_DIR . 'layout/login-ajax.php');
        require_once(KABLE_INC_DIR . 'layout/coming-soon-page.php');        
        require_once(KABLE_INC_DIR . 'configure/header-configure.php');
        require_once(KABLE_INC_DIR . 'configure/blog-configure.php');
        require_once(KABLE_INC_DIR . 'configure/ajax.php');
        require_once(KABLE_INC_DIR . 'configure/template-tags.php');
        require_once(KABLE_INC_DIR . 'configure/sidebar-configure.php');
        require_once(KABLE_INC_DIR . 'configure/dynamic_css.php');
        if(function_exists( 'WC' )){
            require_once(KABLE_INC_DIR . 'woocommerce/function.php');
            require_once(KABLE_INC_DIR . 'woocommerce/notification.php');
            require_once(KABLE_INC_DIR . 'woocommerce/hooks.php');
            require_once(KABLE_INC_DIR . 'woocommerce/vendor/init.php');
        }        
        require_once(KABLE_INC_DIR . 'theme-filter.php');
        require_once(KABLE_INC_DIR . 'register-sidebar.php');
        require_once(KABLE_INC_DIR . 'customizer.php');
        require_once(KABLE_INC_DIR . 'frontend-enqueue.php'); 
        require_once(KABLE_INC_DIR . 'visual-composer/init.php');
    }
    kable_inc_library();
	
	//added
    function modal_scripts(){
    wp_enqueue_script( 'my-dialog', get_stylesheet_directory_uri() .'/js/my-dialog.js', array( 'jquery' ), null, true );

    // If you saved your CSS as a file instead of using the Customizer:
    wp_enqueue_style( 'my-dialog', get_stylesheet_directory_uri() .'/css/my-dialog.css', array(), null );
}
add_action( 'wp_modal', 'modal_scripts' );
function boeckske_dialog_html(){ 
   echo '
<div id="dialog1" title="Basic dialog">
  <p>This is the default dialog which is useful for displaying information. The dialog window can be moved, resized and closed with the  icon.</p>
</div>
';
}
add_action( 'wp_footer', 'boeckske_dialog_html' );	
	
	//end edded
}